==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/EnvironmentVariableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The environment variable to set within the container instance.
 * @property name The name of the environment variable.
 * @property secureValue The value of the secure environment variable.
 * @property value The value of the environment variable.
 */
public data class EnvironmentVariableArgs(
    public val name: Output<String>,
    public val secureValue: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs =
        com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .secureValue(secureValue?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EnvironmentVariableArgs].
 */
@PulumiTagMarker
public class EnvironmentVariableArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var secureValue: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The name of the environment variable.
     */
    @JvmName("vvraesgxbvwdxcdf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The value of the secure environment variable.
     */
    @JvmName("ytcvcwnkaltkkwsi")
    public suspend fun secureValue(`value`: Output<String>) {
        this.secureValue = value
    }

    /**
     * @param value The value of the environment variable.
     */
    @JvmName("fwnmjtuygpaaxtyg")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The name of the environment variable.
     */
    @JvmName("mkmfvngotgdmrlaw")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The value of the secure environment variable.
     */
    @JvmName("leuxmwohlhbqqxsv")
    public suspend fun secureValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureValue = mapped
    }

    /**
     * @param value The value of the environment variable.
     */
    @JvmName("gbglndtlxnfffjlq")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EnvironmentVariableArgs = EnvironmentVariableArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        secureValue = secureValue,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/EnvironmentVariableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The environment variable to set within the container instance.
 * @property name The name of the environment variable.
 * @property secureValue The value of the secure environment variable.
 * @property value The value of the environment variable.
 */
public data class EnvironmentVariableArgs(
    public val name: Output<String>,
    public val secureValue: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs =
        com.pulumi.azurenative.containerinstance.inputs.EnvironmentVariableArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .secureValue(secureValue?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EnvironmentVariableArgs].
 */
@PulumiTagMarker
public class EnvironmentVariableArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var secureValue: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The name of the environment variable.
     */
    @JvmName("aeowybjhctchsfxs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The value of the secure environment variable.
     */
    @JvmName("iwdqcohchpjmblbn")
    public suspend fun secureValue(`value`: Output<String>) {
        this.secureValue = value
    }

    /**
     * @param value The value of the environment variable.
     */
    @JvmName("qmakkyvwcvowlhel")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The name of the environment variable.
     */
    @JvmName("uoswfsatdstlvade")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The value of the secure environment variable.
     */
    @JvmName("mwavphuhbfgmkkjm")
    public suspend fun secureValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureValue = mapped
    }

    /**
     * @param value The value of the environment variable.
     */
    @JvmName("niyhniohrdwvvsxh")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EnvironmentVariableArgs = EnvironmentVariableArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        secureValue = secureValue,
        `value` = `value`,
    )
}
